@@ -1,6 +1,6 @@
 __package__ = "dlg_casacore_components"
 
-from .cbf_sdp import MSStreamingPlasmaProcessor, MSStreamingPlasmaProducer
+from dlg_casacore_components.sdp import MSStreamingPlasmaProcessor, MSStreamingPlasmaProducer
 
 # extend the following as required
 from .ms import MSCopyUpdateApp, MSReadApp
