@@ -26,20 +26,19 @@ import tarfile
 import binascii
 import subprocess
 import unittest
+import io
 from pathlib import Path
 
+import pyarrow
 import pyarrow.plasma as plasma
+import numpy as np
 from casacore import tables
 
-from dlg.drop import FileDROP, PlasmaDROP, InMemoryDROP
+from dlg.drop import FileDROP, PlasmaDROP
 import dlg.droputils as droputils
 
-from cbf_sdp.ms_asserter import MSAsserter
+from realtime.receive.core.ms_asserter import MSAsserter
 from dlg_casacore_components.plasma import MSPlasmaWriter, MSPlasmaReader
-from dlg_casacore_components.cbf_sdp import (
-    MSStreamingPlasmaProcessor,
-    MSStreamingPlasmaProducer,
-)
 
 logging.basicConfig(level=logging.INFO, handlers=[logging.StreamHandler(sys.stdout)])
 
@@ -47,7 +46,7 @@ INPUT_MS_NAME = "test.ms"
 INPUT_MS_ARCHIVE = Path(__file__).parent.absolute() / "data/test_ms.tar.gz"
 
 
-class CRCAppTests(unittest.TestCase):
+class TestPlasma(unittest.TestCase):
     td: TemporaryDirectory
     in_filepath: Path
     out_filepath: Path
@@ -89,10 +88,6 @@ class CRCAppTests(unittest.TestCase):
             self.assertEqual(comparison.all(), True)
 
     def test_plasma_client(self):
-        import pyarrow
-        import io
-        import numpy as np
-
         client = pyarrow.plasma.connect("/tmp/plasma")
         indata = np.ones([10, 10])
 
@@ -126,32 +121,6 @@ class CRCAppTests(unittest.TestCase):
         outdata = np.load(io.BytesIO(buf))
         np.testing.assert_array_equal(indata, outdata)
 
-    def test_plasma_stream(self):
-        prod = MSStreamingPlasmaProducer("1", "1")
-        cons = MSStreamingPlasmaProcessor(
-            "2",
-            "2",
-            processor_max_payloads=133,
-            # TODO: polling currently not blocking at
-            # 1s intervals and timing out
-            processor_timeout=None,
-        )
-        drop = InMemoryDROP("3", "3")
-        ms_in = FileDROP("4", "4", filepath=str(self.in_filepath))
-        ms_out = FileDROP("5", "5", filepath=str(self.out_filepath))
-        prod.addInput(ms_in)
-        prod.addOutput(drop)
-        drop.addStreamingConsumer(cons)
-        cons.addOutput(ms_out)
-
-        with droputils.DROPWaiterCtx(self, cons, 1000):
-            prod.async_execute()
-
-        time.sleep(5)
-        assert Path.is_dir(self.in_filepath), f"{self.in_filepath}"
-        assert Path.is_dir(self.out_filepath), f"{self.out_filepath}"
-        self.compare_measurement_sets(str(self.in_filepath), str(self.out_filepath))
-
     def test_plasma_writer(self):
         a = FileDROP("a", "a", filepath=str(self.in_filepath))
         b = MSPlasmaWriter("b", "b")
